# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelCreateRequest(Model):
    """AnalyticsModelCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.
    :type name: str
    :param version: Required.
    :type version: str
    :param location_id:
    :type location_id: str
    :param corporation_id:
    :type corporation_id: str
    :param group_type: Possible values include: 'Asset', 'Monitoring Point',
     'Indicator Group', 'Group', 'Asset Group'
    :type group_type: str or ~smartdiagnostics_sdk.models.enum
    :param properties:
    :type properties: list[~smartdiagnostics_sdk.models.PropertyRequestChild]
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'version': {'required': True, 'max_length': 50},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'version': {'key': 'Version', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'corporation_id': {'key': 'CorporationId', 'type': 'str'},
        'group_type': {'key': 'GroupType', 'type': 'str'},
        'properties': {'key': 'Properties', 'type': '[PropertyRequestChild]'},
    }

    def __init__(self, **kwargs):
        super(AnalyticsModelCreateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.version = kwargs.get('version', None)
        self.location_id = kwargs.get('location_id', None)
        self.corporation_id = kwargs.get('corporation_id', None)
        self.group_type = kwargs.get('group_type', None)
        self.properties = kwargs.get('properties', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PropertyRequestChild(Model):
    """PropertyRequestChild.

    All required parameters must be populated in order to send to Azure.

    :param property_id: Required.
    :type property_id: int
    :param property_required: Required.
    :type property_required: bool
    """

    _validation = {
        'property_id': {'required': True},
        'property_required': {'required': True},
    }

    _attribute_map = {
        'property_id': {'key': 'PropertyId', 'type': 'int'},
        'property_required': {'key': 'PropertyRequired', 'type': 'bool'},
    }

    def __init__(self, *, property_id: int, property_required: bool, **kwargs) -> None:
        super(PropertyRequestChild, self).__init__(**kwargs)
        self.property_id = property_id
        self.property_required = property_required



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorAlarmStateResponse(Model):
    """IndicatorAlarmStateResponse.

    All required parameters must be populated in order to send to Azure.

    :param current_value:
    :type current_value: float
    :param last_update:
    :type last_update: datetime
    :param id: Required.
    :type id: str
    :param alarm_severity:
    :type alarm_severity: int
    """

    _validation = {
        'id': {'required': True},
    }

    _attribute_map = {
        'current_value': {'key': 'CurrentValue', 'type': 'float'},
        'last_update': {'key': 'LastUpdate', 'type': 'iso-8601'},
        'id': {'key': 'Id', 'type': 'str'},
        'alarm_severity': {'key': 'AlarmSeverity', 'type': 'int'},
    }

    def __init__(self, *, id: str, current_value: float=None, last_update=None, alarm_severity: int=None, **kwargs) -> None:
        super(IndicatorAlarmStateResponse, self).__init__(**kwargs)
        self.current_value = current_value
        self.last_update = last_update
        self.id = id
        self.alarm_severity = alarm_severity
